@@ -75,7 +75,7 @@ def match_columns(request, import_log_id):
         raise SuspiciousOperation("Non superuser attempting to view other users import")
     
     # need to generate matches if they don't exist already
-    import_log.get_matches()
+    existing_matches = import_log.get_matches()
     
     MatchFormSet = inlineformset_factory(ImportSetting, ColumnMatch, form=MatchForm, extra=0)
     
@@ -129,7 +129,7 @@ def match_columns(request, import_log_id):
                     match_relations,
                     kwargs={'import_log_id': import_log.id}))
     else:
-        formset = MatchFormSet(instance=import_log.import_setting)
+        formset = MatchFormSet(instance=import_log.import_setting, queryset=existing_matches)
     
     field_choices = (('', 'Do Not Use'),)
     for field_name in field_names:
@@ -354,7 +354,7 @@ def do_import(request, import_log_id):
                 new_object.simple_import_m2ms = {} # Need to deal with these after saving
                 for i, cell in enumerate(row):
                     if header_row_field_names[i]: # skip blank
-                        if cell or header_row_null_on_empty[i]:
+                        if not import_log.is_empty(cell) or header_row_null_on_empty[i]:
                             set_field_from_cell(import_log, new_object, header_row_field_names[i], cell)
                         elif header_row_default[i]:
                             set_field_from_cell(import_log, new_object, header_row_field_names[i], header_row_default[i])
@@ -362,14 +362,14 @@ def do_import(request, import_log_id):
 
                 for i, cell in enumerate(row):
                     if header_row_field_names[i]: # skip blank
-                        if cell or header_row_null_on_empty[i]:
+                        if not import_log.is_empty(cell) or header_row_null_on_empty[i]:
                             set_method_from_cell(import_log, new_object, header_row_field_names[i], cell)
                         elif header_row_default[i]:
                             set_method_from_cell(import_log, new_object, header_row_field_names[i], header_row_default[i])
 
                 for i, cell in enumerate(row):
                     if header_row_field_names[i]: # skip blank
-                        if cell or header_row_null_on_empty[i]:
+                        if not import_log.is_empty(cell) or header_row_null_on_empty[i]:
                             set_field_from_cell(import_log, new_object, header_row_field_names[i], cell)
                         elif header_row_default[i]:
                             set_field_from_cell(import_log, new_object, header_row_field_names[i], header_row_default[i])
